#!/usr/bin/env python3

import glob
from os.path import basename, normpath
import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
from cycler import cycler

ext = "pdf"

for Re_dir in glob.glob("./Data/Re*/"):

    fig, ax = plt.subplots()
    # Disable ticks.
    ax.xaxis.set_ticks_position('bottom')
    ax.yaxis.set_ticks_position('left')

    ax.set_xticks([-5e-3, -3.75e-3, -2.5e-3])
    ax.set_xticklabels([r'$-2r_{\rm c}$',r'$-1.5r_{\rm c}$', r'$-r_{\rm c}$'])

    # ax.set_xlabel('Vorticity')
    ax.set_ylabel(r'$n_{\rm p}$', rotation=0)
    # ax.set_xlim([x_min, x_max])
    # ax.set_xticks(np.arange(x_min, x_max+1, 30))
    # ax.set_yticks(np.arange(y_min, y_max, 0.1))

    ax.set_prop_cycle(cycler('color', 'bgr') + cycler('marker', ['o', 's', 'x']))

    f = normpath(Re_dir) + "/Eul/St005.csv"
    df = pd.read_csv(f, names=["x", "y", "c"])
    ax.plot(df['x'].values, df['c'].values, label="Stk = 0.05", clip_on=False)

    f = normpath(Re_dir) + "/Eul/St01.csv"
    df = pd.read_csv(f, names=["x", "y", "c"])
    ax.plot(df['x'].values, df['c'].values, label="Stk = 0.1", clip_on=False)

    f = normpath(Re_dir) + "/Eul/St02.csv"
    df = pd.read_csv(f, names=["x", "y", "c"])
    ax.plot(df['x'].values, df['c'].values, label="Stk = 0.2", clip_on=False)

    ax.set_prop_cycle(cycler('color', 'bgr') + cycler('marker', ['o', 's', 'x']))

    f = normpath(Re_dir) + "/DPM/St005.csv"
    df = pd.read_csv(f, names=["x", "y", "c"])
    ax.plot(df['x'].values, df['c'].values, ls ="--", clip_on=False)

    f = normpath(Re_dir) + "/DPM/St01.csv"
    df = pd.read_csv(f, names=["x", "y", "c"])
    ax.plot(df['x'].values, df['c'].values, ls ="--", clip_on=False)

    f = normpath(Re_dir) + "/DPM/St02.csv"
    df = pd.read_csv(f, names=["x", "y", "c"])
    ax.plot(df['x'].values, df['c'].values, ls ="--", clip_on=False)

    ax.legend()
    ax.legend(loc='upper left', numpoints=1)
    plot_fname = "./Plots/c_along_x_{0}.{1}".format(basename(normpath(Re_dir)), ext)
    fig.savefig(plot_fname)

exit()

