#!/usr/bin/env python3

import numpy as np
import pandas as pd
import matplotlib.pyplot as plt

read_mask = './n_vs_vort_Re200_St{0}.csv'
vort_min, vort_max = 0, 800 
x_min, x_max = 0, vort_max/5
y_min, y_max = 0, 0.5

fig, ax = plt.subplots()
# Disable ticks.
ax.xaxis.set_ticks_position('bottom')
ax.yaxis.set_ticks_position('left')
ax.set_xlabel('Vorticity')
ax.set_ylabel('Relative number of particles')
ax.set_xlim([x_min, x_max])
ax.set_xticks(np.arange(x_min, x_max+1, 30))
ax.set_yticks(np.arange(y_min, y_max, 0.1))

for Stk in [0.05, 0.1, 0.2]:
    df = pd.read_csv(read_mask.format(str(Stk)))
    ax.plot(df['vort'].values, df['n'].values, label="Stk = " + str(Stk))

ax.legend()
fig.savefig("./n_vs_vort.pdf")

