#!/usr/bin/env gnuplot

reset

set terminal pdf dashed size 3.9,5.0 #7,11
ext="pdf"
dir="./by_time"

# Axes
set border 2+4 back
set tics nomirror out scale 0.55

# Equal ration and margins
set size ratio -1
set autoscale fix
set lmargin at screen 0.12;
set rmargin at screen 0.97;
set bmargin at screen 0.10;
set tmargin at screen 0.95;

unset key

# Prepare to read the data 
Basename(filename)=system("basename ".filename." | cut -d. -f1")
filelist=system("find ".dir."/data/ -type f -name '*.csv'")
set datafile separator ","

do for [filename in filelist] {

    outfile = sprintf("%s/Plots/%s.%s", dir, Basename(filename), ext)
    frame = sprintf("%s/Video_frames/%s.png", dir, Basename(filename))
    set output outfile

    set multiplot

    # Use video frame from experiment as a background
    unset tics
    unset cbrange
    set xrange [370:790]
    set yrange [50:590]
    plot frame binary filetype=png w rgbimage 

    set ytics
    set x2tics
    set xrange [0:0.06]
    set yrange [-0.08:0]

    # plot injector tip
    set arrow from 4e-3,0   to 4e-3,-6e-3 nohead
    set arrow from 0,-10e-3 to 4e-3,-6e-3 nohead

    # plot the droplets
    set cbtics
    set colorbox horizontal user origin 0.12,0.04 size 0.8,0.04
    plot filename u 4:(-$3):5 w points pt 7 ps 0.1 lt palette

    unset multiplot
}
